desub is a Python module to work with a detached subprocess.

This is useful for making a web interface (or whatever) to monitor a
process running in the background. You can start a
process from a web request and serve subsequent requests
to report status on and show output for the process you started earlier.

Full documentation: http://desub.readthedocs.org/en/latest/
